==> kubernetes-model-admissionregistration-5.9.0-sources.jar: io/fabric8/kubernetes/api/model/admissionregistration/v1beta1/ValidatingWebhookConfigurationBuilder.java <==
package io.fabric8.kubernetes.api.model.admissionregistration.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ValidatingWebhookConfigurationBuilder extends io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.ValidatingWebhookConfigurationFluentImpl<io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.ValidatingWebhookConfigurationBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.ValidatingWebhookConfiguration,io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.ValidatingWebhookConfigurationBuilder>{
  public ValidatingWebhookConfigurationBuilder() {
    this(false);
  }
  public ValidatingWebhookConfigurationBuilder(java.lang.Boolean validationEnabled) {
    this(new ValidatingWebhookConfiguration(), validationEnabled);
  }
  public ValidatingWebhookConfigurationBuilder(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.ValidatingWebhookConfigurationFluent<?> fluent) {
    this(fluent, false);
  }
  public ValidatingWebhookConfigurationBuilder(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.ValidatingWebhookConfigurationFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ValidatingWebhookConfiguration(), validationEnabled);
  }
  public ValidatingWebhookConfigurationBuilder(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.ValidatingWebhookConfigurationFluent<?> fluent,io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.ValidatingWebhookConfiguration instance) {
    this(fluent, instance, false);
  }
  public ValidatingWebhookConfigurationBuilder(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.ValidatingWebhookConfigurationFluent<?> fluent,io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.ValidatingWebhookConfiguration instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withWebhooks(instance.getWebhooks()); 
    this.validationEnabled = validationEnabled; 
  }
  public ValidatingWebhookConfigurationBuilder(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.ValidatingWebhookConfiguration instance) {
    this(instance,false);
  }
  public ValidatingWebhookConfigurationBuilder(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.ValidatingWebhookConfiguration instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withWebhooks(instance.getWebhooks()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.ValidatingWebhookConfigurationFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.ValidatingWebhookConfiguration build() {
    ValidatingWebhookConfiguration buildable = new ValidatingWebhookConfiguration(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getWebhooks());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ValidatingWebhookConfigurationBuilder that = (ValidatingWebhookConfigurationBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-admissionregistration-5.12.2-sources.jar: io/fabric8/kubernetes/api/model/admissionregistration/v1beta1/ValidatingWebhookConfigurationBuilder.java <==
package io.fabric8.kubernetes.api.model.admissionregistration.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ValidatingWebhookConfigurationBuilder extends io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.ValidatingWebhookConfigurationFluentImpl<io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.ValidatingWebhookConfigurationBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.ValidatingWebhookConfiguration,io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.ValidatingWebhookConfigurationBuilder>{
  public ValidatingWebhookConfigurationBuilder() {
    this(false);
  }
  public ValidatingWebhookConfigurationBuilder(java.lang.Boolean validationEnabled) {
    this(new ValidatingWebhookConfiguration(), validationEnabled);
  }
  public ValidatingWebhookConfigurationBuilder(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.ValidatingWebhookConfigurationFluent<?> fluent) {
    this(fluent, false);
  }
  public ValidatingWebhookConfigurationBuilder(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.ValidatingWebhookConfigurationFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ValidatingWebhookConfiguration(), validationEnabled);
  }
  public ValidatingWebhookConfigurationBuilder(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.ValidatingWebhookConfigurationFluent<?> fluent,io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.ValidatingWebhookConfiguration instance) {
    this(fluent, instance, false);
  }
  public ValidatingWebhookConfigurationBuilder(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.ValidatingWebhookConfigurationFluent<?> fluent,io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.ValidatingWebhookConfiguration instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withWebhooks(instance.getWebhooks()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ValidatingWebhookConfigurationBuilder(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.ValidatingWebhookConfiguration instance) {
    this(instance,false);
  }
  public ValidatingWebhookConfigurationBuilder(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.ValidatingWebhookConfiguration instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withWebhooks(instance.getWebhooks()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.ValidatingWebhookConfigurationFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.ValidatingWebhookConfiguration build() {
    ValidatingWebhookConfiguration buildable = new ValidatingWebhookConfiguration(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getWebhooks());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ValidatingWebhookConfigurationBuilder that = (ValidatingWebhookConfigurationBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
